# This file is part of phishdetect-python:
# https://github.com/phishdetect/phishdetect-python
# See the file 'LICENSE' for copying permission.

class Model:

    def __init__(self, phishdetect):
        self._phishdetect = phishdetect
