# This file is part of phishdetect-python:
# https://github.com/phishdetect/phishdetect-python
# See the file 'LICENSE' for copying permission.

from .alerts import Alerts
from .indicators import Indicators
from .reports import Reports
from .users import Users
from .analyze import Analyze
